package sbservermonitor

import (
	"github.com/prometheus/client_golang/prometheus"
)

const (
	namespace = "sb_server_monitor"

	metricLabelServerID                  = "id"
	metricLabelServerName                = "name"
	metricLabelServerCategory            = "category"
	metricLabelServerCPU                 = "cpu"
	metricLabelServerDrives              = "drives"
	metricLabelServerMemory              = "memory"
	metricLabelServerECC                 = "ecc"
	metricLabelServerHighIO              = "highio"
	metricLabelServerDatacenter          = "datacenter"
	metricLabelServerDescription         = "description"
	metricLabelServerDist                = "dist"
	metricLabelServerInformation         = "information"
	metricLabelServerPrice               = "price"
	metricLabelServerFixedPrice          = "fixed_price"
	metricLabelServerNextReduce          = "next_reduce"
	metricLabelServerNextReduceTimestamp = "next_reduce_timestamp"
	metricLabelServerGeneralDrives       = "general_drives"
	metricLabelServerHDDs                = "hdds"
	metricLabelServerSATAs               = "sata"
	metricLabelServerNVMes               = "nvme"
	metricLabelServerSetupPrice          = "setup_price"
	metricLabelServerSpecials            = "specials"
	metricLabelServerBandwidth           = "bandwidth"
	metricLabelServerTraffic             = "traffic"
)

var (
	metricServerCount = prometheus.NewDesc(
		prometheus.BuildFQName(
			namespace,
			"server",
			"current_available",
		),
		"total number of all current available servers",
		[]string{
			metricLabelServerCategory,
		},
		nil,
	)

	metricServerCountPerPrice = prometheus.NewDesc(
		prometheus.BuildFQName(
			namespace,
			"server",
			"current_available_per_price",
		),
		"total number of all current available servers per price",
		[]string{
			metricLabelServerPrice,
		},
		nil,
	)

	metricServerCountPerDatacenter = prometheus.NewDesc(
		prometheus.BuildFQName(
			namespace,
			"server",
			"current_available_per_datacenter",
		),
		"total number of all current available servers per datacenter",
		[]string{
			metricLabelServerDatacenter,
		},
		nil,
	)

	metricServers = prometheus.NewDesc(
		prometheus.BuildFQName(
			namespace,
			"",
			"servers",
		),
		"list all servers with some useful information as labels",
		[]string{
			metricLabelServerID,
			metricLabelServerName,
			metricLabelServerCategory,
			metricLabelServerCPU,
			metricLabelServerDatacenter,
			metricLabelServerInformation,
			metricLabelServerPrice,
			metricLabelServerFixedPrice,
			metricLabelServerNextReduceTimestamp,
		},
		nil,
	)
)
