package hrobot

import (
	"context"
	"time"

	"git.ar21.de/yolokube/sb-server-monitor/hrobot/schema"
)

type SbServer struct {
	ID      int64
	Name    string
	Key     int64
	Network struct {
		Bandwidth int64
		Traffic   string
	}
	CatID    int64
	Category string
	Hardware struct {
		CPU         string
		CPUCount    int8
		Drives      []string
		DrivesCount int8
		DrivesHr    []string
		DrivesSize  int64
		Memory      []string
		MemorySize  int64
		ECC         bool
		HighIO      bool
	}
	Datacenter       string
	DatacenterHr     string
	Description      []string
	Dist             []string
	Information      []string
	PriceInformation struct {
		FixedPrice          bool
		NextReduce          int64
		NextReduceHr        bool
		NextReduceTimestamp time.Time
		Price               int64
		SetupPrice          int64
	}
	DiskData struct {
		General []int
		HDD     []int
		NVMe    []int
		SATA    []int
	}
	Specials []string
}

type SbServerClient struct {
	client *Client
}

func (c *SbServerClient) List(ctx context.Context) ([]*SbServer, error) {
	req, err := c.client.NewRequest(ctx, "GET", "", nil)
	if err != nil {
		return nil, err
	}

	var body schema.SbServerList
	_, err = c.client.Do(req, &body)
	if err != nil {
		return nil, err
	}

	var servers []*SbServer
	for _, s := range body.SbServers {
		servers = append(servers, SbServerFromSchema(s))
	}
	return servers, nil
}
